@@ -4,7 +4,7 @@ from .track import Track
 
 class Album:
 	def __init__(self, ids: int) -> None:
-		self.__t_list = []
+		self.tracks: list[Track] = []
 		self.zip_path = None
 		self.image = None
 		self.album_quality = None
@@ -13,11 +13,8 @@ class Album:
 		self.nb_tracks = None
 		self.album_name = None
 		self.upc = None
+		self.tags = None
 		self.__set_album_md5()
 
-	@property
-	def tracks(self) -> list[Track]:
-		return self.__t_list
-
 	def __set_album_md5(self):
 		self.album_md5 = f"album/{self.ids}"
\ No newline at end of file
