@@ -4,9 +4,5 @@ from .track import Track
 
 class Playlist:
 	def __init__(self) -> None:
-		self.__t_list = []
-		self.zip_path = None
-
-	@property
-	def tracks(self) -> list[Track]:
-		return self.__t_list
\ No newline at end of file
+		self.tracks: list[Track] = []
+		self.zip_path = None
\ No newline at end of file
